@@ -169,9 +169,9 @@ RankMaps <- function(pl, p, mapDF, att){
 			colour=att[[p]]$active.border.color, 
 			size=att[[p]]$active.border.size/2, 
 			data=subset(mapDF, hole==0)) + 				
-		facet_grid(pGrp~., scales="free_y", space="free") +
+		facet_grid(pGrp~., space="free", scales="free_y") +
 		scale_fill_manual(values=c(att$colors), guide='none') +
-		coord_equal() 
+		coord_cartesian()  
 
 
 	  #################################
@@ -190,7 +190,8 @@ RankMaps <- function(pl, p, mapDF, att){
 			geom_polygon(fill='white', colour='white', data=mapDF.median) + 
 				geom_text(aes(x=textx, y=texty, label=tmp.label, hjust=.5, vjust=.4),
 						colour=att$median.text.color, size=5*att$median.text.size, data=mapDF.median) +
-				facet_grid(pGrp~., scales="free_y", space="free")
+				facet_grid(pGrp~., scales="free_y", space="free") +
+	      coord_cartesian() 
 
 	  #################################
 	  #################################
@@ -248,7 +249,6 @@ RankMaps <- function(pl, p, mapDF, att){
 	 }
 
 
-
 	ystr <- paste("scale_y_continuous('', breaks=NULL, expand=c(0,0))")
 
 	pl <- pl + eval(parse(text=ystr))
@@ -256,7 +256,7 @@ RankMaps <- function(pl, p, mapDF, att){
 	pl  <- plot_opts(p, pl, att)		
 	pl  <- graph_opts(p, pl, att)	
 
-	pl <- pl + theme(panel.margin = unit(0, "lines"))
+	pl <- pl + theme(panel.spacing = unit(0, "lines"))
 
 
 	pl 
@@ -276,8 +276,8 @@ CatMaps <- function(pl, p, mapDF, att){
 		geom_polygon(fill=att$map.color, colour='black', data=subset(mapDF, hole==0)) + 				
 		geom_polygon(fill='white', colour='black', data=subset(mapDF, hole==1)) +
 		geom_polygon(fill='transparent', colour='black', data=subset(transform(mapDF, pGrp=NULL), hole==1)) +
-		facet_grid(pGrp~., scales="free_y", space="free") +
-		coord_equal() 
+		facet_grid(pGrp~., scales = "free_y", space="free") +
+		coord_cartesian()  
 
 
 
@@ -322,14 +322,13 @@ CatMaps <- function(pl, p, mapDF, att){
 				theme(axis.ticks = element_blank()) 
 	 }
 
-
 #	ystr <- paste("scale_y_continuous('', breaks=NULL, expand=c(",pGrp.spacing,",",pGrp.spacing,"))")
 	ystr <- paste("scale_y_continuous('', breaks=NULL, expand=c(0,0))")
 	pl <- pl + eval(parse(text=ystr))
 
 	pl  <- plot_opts(p, pl, att)		
 	pl  <- graph_opts(p, pl, att)	
-	pl <- pl + theme(panel.margin = unit(0, "lines")) 
+	pl <- pl + theme(panel.spacing = unit(0, "lines")) 
 
 	pl
 
